@@ -1,4 +1,5 @@
 import urllib.request
+from sseclient import SSEClient
 
 
 class Connection:
@@ -27,5 +28,7 @@ class Connection:
         reply = urllib.request.urlopen(request, timeout=timeout)
         return reply
 
-
+    def sse(self, path):
+        messages = SSEClient(url="http://" + self.host + ":" + str(self.port) + "/" + path)
+        return messages
 
