@@ -78,10 +78,10 @@ class Events:
                 args += ","
         return self.__reply_status_check(self.device.con.get(path="sendTouchEvent", args="points=" + args))
 
-    def slide(self, x1, y1, x2, y2):
+    def swipe(self, x1, y1, x2, y2):
         return self.__reply_status_check(self.device.con.get(path="sendSlideEvent", args="sliders=" + str(x1) + "|" + str(y1) + "->" + str(x2) + "|" + str(y2)))
 
-    def multi_slide(self, points1, points2):
+    def multi_swipe(self, points1, points2):
         args = ""
         for point1 in points1:
             args += str(point1[0]) + "|" + str(point1[1]) + "->" + str(points2[points1.index(point1)][0]) + "|" + str(points2[points1.index(point1)][1])
